@@ -494,7 +494,7 @@ class DataTransformerForm(BaseInlineFormSet):
                                                              )
         if form.instance is not None:
             form.nested_data_transformer_form = dataTransformerInlineFormset(
-                instance=form.instance,
+                initial=form.instance.getChildren(),
                 data=form.data if form.is_bound else None,
                 files=form.files if form.is_bound else None
             )
@@ -518,7 +518,22 @@ class DataTransformerForm(BaseInlineFormSet):
             )
 
     def as_p(self):
-        forms = ' '.join(' '.join([form.as_p(),form.nested_data_transformer_form.as_p(),form.nested_constants_form.as_p(),form.nested_hardware_outputs_form.as_p(),form.nested_hardware_stats_form.as_p()]) for form in self)
+        # super(self.__class__,self).as_p()
+        forms = ' '
+        for form in self:
+            forms.join(form.as_p())
+            if form.nested_data_transformer_form is not None:
+                forms.join(form.nested_data_transformer_form.as_p())
+            if form.nested_constants_form is not None:
+
+                forms.join(form.nested_constants_form.as_p())
+            if form.nested_hardware_outputs_form is not None:
+
+                forms.join(form.nested_hardware_outputs_form.as_p())
+            if form.nested_hardware_stats_form is not None:
+
+                forms.join(form.nested_hardware_stats_form.as_p())
+
         return mark_safe(str(self.management_form) + '\n' + forms)
 
 
